You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2019/08/06 21:25:47 UTC

[commons-io] branch master updated: Slightly better internal names.

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-io.git


The following commit(s) were added to refs/heads/master by this push:
     new f4da675  Slightly better internal names.
f4da675 is described below

commit f4da6751ac53fb2949db35b861e6584e66752f15
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Tue Aug 6 17:25:42 2019 -0400

    Slightly better internal names.
---
 .../testtools/YellOnFlushAndCloseOutputStream.java | 22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

diff --git a/src/test/java/org/apache/commons/io/testtools/YellOnFlushAndCloseOutputStream.java b/src/test/java/org/apache/commons/io/testtools/YellOnFlushAndCloseOutputStream.java
index 5addec4..2660794 100644
--- a/src/test/java/org/apache/commons/io/testtools/YellOnFlushAndCloseOutputStream.java
+++ b/src/test/java/org/apache/commons/io/testtools/YellOnFlushAndCloseOutputStream.java
@@ -28,24 +28,24 @@ import junit.framework.AssertionFailedError;
  */
 public class YellOnFlushAndCloseOutputStream extends ProxyOutputStream {
 
-    private boolean yellForFlush;
-    private boolean yellForClose;
+    private boolean yellOnFlush;
+    private boolean yellOnClose;
 
     /**
      * @param proxy OutputStream to delegate to.
      * @param yellForFlush True if flush() is forbidden
      * @param yellForClose True if close() is forbidden
      */
-    public YellOnFlushAndCloseOutputStream(final OutputStream proxy, final boolean yellForFlush, final boolean yellForClose) {
+    public YellOnFlushAndCloseOutputStream(final OutputStream proxy, final boolean yellOnFlush, final boolean yellOnClose) {
         super(proxy);
-        this.yellForFlush = yellForFlush;
-        this.yellForClose = yellForClose;
+        this.yellOnFlush = yellOnFlush;
+        this.yellOnClose = yellOnClose;
     }
 
     /** @see java.io.OutputStream#flush() */
     @Override
     public void flush() throws IOException {
-        if (yellForFlush) {
+        if (yellOnFlush) {
             throw new AssertionFailedError("flush() was called on OutputStream");
         }
         super.flush();
@@ -54,15 +54,15 @@ public class YellOnFlushAndCloseOutputStream extends ProxyOutputStream {
     /** @see java.io.OutputStream#close() */
     @Override
     public void close() throws IOException {
-        if (yellForClose) {
+        if (yellOnClose) {
             throw new AssertionFailedError("close() was called on OutputStream");
         }
         super.close();
     }
 
     public void off() {
-        yellForFlush = false;
-        yellForClose = false;
+        yellOnFlush = false;
+        yellOnClose = false;
     }
 
 }
@@ -28,24 +28,24 @@ import junit.framework.AssertionFailedError;
     /**
      * @param proxy OutputStream to delegate to.
-     * @param yellForFlush True if flush() is forbidden
-     * @param yellForClose True if close() is forbidden
+     * @param yellOnFlush True if flush() is forbidden
+     * @param yellOnClose True if close() is forbidden
      */